@@ -6,8 +6,9 @@
   if(!memoise_option %in% c("memory", "filesystem", "off")) memoise_option <- "memory"
 
   if(memoise_option == "filesystem"){
-    cache_dir <- rappdirs::user_cache_dir(appname = "nflplotR")
-    dir.create(cache_dir, recursive = TRUE, showWarnings = FALSE)
+    backports::import(pkgname, "R_user_dir")
+    cache_dir <- R_user_dir("nflplotR", "cache")
+    if (!dir.exists(cache_dir)) dir.create(cache_dir, recursive = TRUE, showWarnings = FALSE)
     cache <- cachem::cache_disk(dir = cache_dir)
   }
 
